ChipOptions

Struct ChipOptions 

pub struct ChipOptions {
    pub io_key_enabled: bool,
    pub io_key_in_slot: u8,
    pub aes_enabled: bool,
    pub kdf_aes_enabled: bool,
    pub ecdh_output_protection: OutputProtectionState,
    pub kdf_output_protection: OutputProtectionState,
    pub kdf_iv_enabled: bool,
    pub kdf_iv_location_at: usize,
    pub kdf_iv_str: [u8; 2],
}
structure that stores data for options supported by the chip

Fields

io_key_enabled: bool

If true, then the protection functions are enabled via the secret key stored in the slot indicated by io_key_in_slot. If false, the security functions are disabled and fields ‘io_key_in_slot’, ‘ecdh_output_protection’ and ‘kdf_output_protection’ are irrelevant (only relevant for the ATECC608x chip)

io_key_in_slot: u8

slot number where the key for encrypting transmission between chip and host is placed

aes_enabled: bool

flag, on-chip availability, AES function

kdf_aes_enabled: bool

flag, on-chip availability, AES functionality for KDF command

ecdh_output_protection: OutputProtectionState

restrictions on the way the ECDH command result can be used

kdf_output_protection: OutputProtectionState

restrictions on the way the KDF command result can be used

kdf_iv_enabled: bool

availability flag of the special function of the IV KDF command

kdf_iv_location_at: usize

place in message where special data bytes must be placed when calling function IV of the KDF command

kdf_iv_str: [u8; 2]

two bytes of data that must be included in message when calling function IV of the KDF command